/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Initial Developer of the Original Code is Malte Kraus.
 *
 * Contributor(s):
 *  Malte Kraus <firefox@maltekraus.de> (Original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

const Cc = Components.classes, Ci = Components.interfaces;

function savePassword() {
  var tokendb = Components.classes["@mozilla.org/security/pk11tokendb;1"]
                          .createInstance(Components.interfaces.nsIPK11TokenDB);
  var token = tokendb.getInternalKeyToken();

  if(!token.isLoggedIn()) {
    try {
      token.login(true);
      if(!token.isLoggedIn())
        return;
    } catch(e) {
      return;
    }
  }

  var user = document.getElementById("textbox-ftp-user").value;
  var password = document.getElementById("textbox-ftp-pass").value;
  var host = document.getElementById("textbox-ftp-host").value;
  var passwordManager = Cc["@mozilla.org/passwordmanager;1"]
                          .createInstance(Ci.nsIPasswordManager);
  try { passwordManager.removeUser(host, user); } catch(e) {}
  passwordManager.addUser(host, user, password);
}

function initPassword() {
  var user = document.getElementById("textbox-ftp-user").value;
  var host = document.getElementById("textbox-ftp-host").value;
  // This doesn't harm if passwords are not encrypted
  var tokendb = Components.classes["@mozilla.org/security/pk11tokendb;1"]
                          .createInstance(Components.interfaces.nsIPK11TokenDB);
  var token = tokendb.getInternalKeyToken();

  if(!token.isLoggedIn()) {
    try {
      if(!token.checkPassword("")) {
        // So there's a master password. But since checkPassword didn't succeed,
        // we're logged out (per nsIPK11Token.idl).
        // Relogin and ask for the master password.
        token.login(true);  // 'true' means always prompt for token password.
                            // User will be prompted until clicking 'Cancel' or
                            // entering the correct password.

        // An exception will be thrown if the user cancels the login prompt
        // dialog. User is also logged out of Software Security Device.
      }
    } catch(e) {
      if(!token.isLoggedIn()) { // cancel
        //document.getElementById("textbox-ftp-pass").disabled = true;
        return;
      }
    }
  }

  var passwordManager = Components.classes["@mozilla.org/passwordmanager;1"]
                      .createInstance(Components.interfaces.nsIPasswordManager);
  var passwords = passwordManager.enumerator;
  while(passwords.hasMoreElements()) {
    var password = passwords.getNext();
    password.QueryInterface(Components.interfaces.nsIPassword);
    if(password.host == host && password.user == user) {
      var textbox = document.getElementById("textbox-ftp-pass");
      textbox.defaultValue = password.password;
      textbox.value = textbox.defaultValue;
      break;
    }
  }
}

function initUploadPane() {
  initPassword();
  var appInfo = Cc["@mozilla.org/xre/app-info;1"]
                  .createInstance(Ci.nsIXULAppInfo);
  var app = appInfo.ID;
  document.getElementById("pref-auto-upload").disabled = (
                            (app == "{758DAD28-FDE9-4ab8-A301-3FFFAB3A697A}") ||
                            (app == "songbird@songbirdnest.com"));
}